# battery-bus: parts

|   |   |   |   |   |   |
| --- | --- | --- | --- | --- | --- |
| [`DC power plug, 5.5 mm`](../parts/dc-power-plug.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/charging-port.jpg?raw=true)](../parts/dc-power-plug.md)  | [`DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter`](../parts/dsn-vc288.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dsn-vc288.jpg?raw=true)](../parts/dsn-vc288.md)  | [`Li-Ion battery`](../parts/li-ion-battery.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/lithium-battery.jpg?raw=true)](../parts/li-ion-battery.md) option 2️⃣, e.g. 3 x 26650, 5000 mAh 5C, 3.7 V/4.2 V | [`Rechargeable sealed lead acid battery`](../parts/SLA-Battery.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/battery.png?raw=true)](../parts/SLA-Battery.md) option 1️⃣, e.g. 12 V, 7.2 Ah | [`auto power connectors`](../parts/connector.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/connector.jpg?raw=true)](../parts/connector.md) 1 male | [`on/off DC switch with indicator led`](../parts/dc-switch.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/on-off-switch.png?raw=true)](../parts/dc-switch.md) 12V DC 10 A |

1. [DC power plug, 5.5 mm](../parts/dc-power-plug.md).
1. [DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter](../parts/dsn-vc288.md).
1. [Li-Ion battery](../parts/li-ion-battery.md): option 2️⃣, e.g. 3 x 26650, 5000 mAh 5C, 3.7 V/4.2 V.
1. [Rechargeable sealed lead acid battery](../parts/SLA-Battery.md): option 1️⃣, e.g. 12 V, 7.2 Ah.
1. [auto power connectors](../parts/connector.md): 1 male.
1. [on/off DC switch with indicator led](../parts/dc-switch.md): 12V DC 10 A.
